@@ -12,16 +12,16 @@ impl<T> Request<T> {
 	pub fn new(method: impl ToString, tag: u8, arguments: T) -> Self {
 		Self{
 			method: method.to_string(),
-			tag: tag,
-			arguments: arguments
+			tag,
+			arguments
 		}
 	}
 }
 
 #[derive(Debug, Deserialize)]
 pub struct Response<T> {
-	result: String,
-	tag: u8,
+	_result: String,
+	_tag: u8,
 	pub arguments: T
 }
 
